@@ -1,5 +1,6 @@
 from autoarray.util import transformer_util
 from autoarray.structures import arrays, visibilities as vis
+from autoarray.util import array_util
 from astropy import units
 from scipy import interpolate
 from pynufft import NUFFT_cpu
@@ -34,7 +35,7 @@ class TransformerDFT:
 
         if self.preload_transform:
 
-            return transformer_util.real_visibilities_from_image_via_preload_jit(
+            return transformer_util.real_visibilities_via_preload_jit_from(
                 image_1d=image.in_1d_binned,
                 preloaded_reals=self.preload_real_transforms,
             )
@@ -51,7 +52,7 @@ class TransformerDFT:
 
         if self.preload_transform:
 
-            return transformer_util.imag_visibilities_from_image_via_preload_jit(
+            return transformer_util.imag_visibilities_from_via_preload_jit_from(
                 image_1d=image.in_1d_binned,
                 preloaded_imags=self.preload_imag_transforms,
             )
@@ -77,7 +78,7 @@ class TransformerDFT:
 
         if self.preload_transform:
 
-            return transformer_util.real_transformed_mapping_matrix_via_preload_jit(
+            return transformer_util.real_transformed_mapping_matrix_via_preload_jit_from(
                 mapping_matrix=mapping_matrix,
                 preloaded_reals=self.preload_real_transforms,
             )
@@ -94,7 +95,7 @@ class TransformerDFT:
 
         if self.preload_transform:
 
-            return transformer_util.imag_transformed_mapping_matrix_via_preload_jit(
+            return transformer_util.imag_transformed_mapping_matrix_via_preload_jit_from(
                 mapping_matrix=mapping_matrix,
                 preloaded_imags=self.preload_imag_transforms,
             )
@@ -254,7 +255,7 @@ class TransformerNUFFT(NUFFT_cpu):
             )
         )
 
-    def initialize_plan(self, ratio=2, interpolation_kernel=(6, 6)):
+    def initialize_plan(self, ratio=2, interp_kernel=(6, 6)):
 
         if not isinstance(ratio, int):
             ratio = int(ratio)
@@ -276,7 +277,7 @@ class TransformerNUFFT(NUFFT_cpu):
             visibilities_normalized,
             self.grid.shape_2d,
             (ratio * self.grid.shape_2d[0], ratio * self.grid.shape_2d[1]),
-            interpolation_kernel,
+            interp_kernel,
         )
 
     def visibilities_from_image(self, image):
@@ -305,10 +306,14 @@ class TransformerNUFFT(NUFFT_cpu):
 
         for source_pixel_1d_index in range(mapping_matrix.shape[1]):
 
-            image = self.grid.mask.mapping.array_stored_2d_from_array_1d(
-                array_1d=mapping_matrix[:, source_pixel_1d_index]
+            image_2d = array_util.sub_array_2d_from(
+                sub_array_1d=mapping_matrix[:, source_pixel_1d_index],
+                mask=self.grid.mask,
+                sub_size=1,
             )
 
+            image = arrays.Array(array=image_2d, mask=self.grid.mask, store_in_1d=False)
+
             visibilities = self.visibilities_from_image(image=image)
 
             real_transfomed_mapping_matrix[:, source_pixel_1d_index] = visibilities.real
