@@ -20,7 +20,7 @@ class TestRectangular:
             ]
         )
 
-        mask = aa.Mask.manual(mask_2d=mask, pixel_scales=1.0, sub_size=1)
+        mask = aa.Mask.manual(mask=mask, pixel_scales=1.0, sub_size=1)
 
         # Source-plane comprises 5 grid, so 5 masked_image pixels traced to the pix-plane.
 
@@ -112,7 +112,7 @@ class TestRectangular:
             ]
         )
 
-        mask = aa.Mask.manual(mask_2d=mask, pixel_scales=1.0, sub_size=1)
+        mask = aa.Mask.manual(mask=mask, pixel_scales=1.0, sub_size=1)
 
         # There is no sub-grid, so our grid are just the masked_image grid (note the NumPy weighted_data structure
         # ensures this has no sub-gridding)
@@ -227,7 +227,7 @@ class TestRectangular:
             ]
         )
 
-        mask = aa.Mask.manual(mask_2d=mask, pixel_scales=2.0, sub_size=2)
+        mask = aa.Mask.manual(mask=mask, pixel_scales=2.0, sub_size=2)
 
         # Assume a 2x2 sub-grid, so each of our 5 masked_image-pixels are split into 4.
         # The grid below is unphysical in that the (0.0, 0.0) terms on the end of each sub-grid probably couldn't
@@ -337,7 +337,7 @@ class TestRectangular:
             ]
         )
 
-        mask = aa.Mask.manual(mask_2d=mask, pixel_scales=1.0, sub_size=1)
+        mask = aa.Mask.manual(mask=mask, pixel_scales=1.0, sub_size=1)
 
         grid = aa.MaskedGrid.manual_1d(
             grid=np.array(
@@ -425,10 +425,10 @@ class TestRectangular:
         )
 
         real_space_mask = aa.Mask.manual(
-            mask_2d=real_space_mask, pixel_scales=0.1, sub_size=1
+            mask=real_space_mask, pixel_scales=0.1, sub_size=1
         )
 
-        grid = aa.MaskedGrid.from_mask(mask=real_space_mask)
+        grid = aa.Grid.from_mask(mask=real_space_mask)
 
         pix = aa.pix.Rectangular(shape=(7, 7))
 
@@ -480,7 +480,7 @@ class TestVoronoiMagnification:
     def test__3x3_simple_grid(self):
 
         mask = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [
                     [True, True, True, True, True],
                     [True, False, False, False, True],
@@ -510,12 +510,12 @@ class TestVoronoiMagnification:
         grid = aa.MaskedGrid.manual_1d(grid=grid, mask=mask)
 
         pix = aa.pix.VoronoiMagnification(shape=(3, 3))
-        sparse_grid = grids.SparseGrid.from_grid_and_unmasked_2d_grid_shape(
+        sparse_grid = grids.GridSparse.from_grid_and_unmasked_2d_grid_shape(
             grid=grid, unmasked_sparse_shape=pix.shape
         )
 
         pixelization_grid = aa.GridVoronoi(
-            grid_1d=sparse_grid.sparse,
+            grid=sparse_grid.sparse,
             nearest_pixelization_1d_index_for_mask_1d_index=sparse_grid.sparse_1d_index_for_mask_1d_index,
         )
 
@@ -592,7 +592,7 @@ class TestVoronoiMagnification:
     def test__3x3_simple_grid__include_mask(self):
 
         mask = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [
                     [True, True, True, True, True],
                     [True, True, False, True, True],
@@ -610,12 +610,12 @@ class TestVoronoiMagnification:
         grid = aa.MaskedGrid.manual_1d(grid=grid, mask=mask)
 
         pix = aa.pix.VoronoiMagnification(shape=(3, 3))
-        sparse_grid = grids.SparseGrid.from_grid_and_unmasked_2d_grid_shape(
+        sparse_grid = grids.GridSparse.from_grid_and_unmasked_2d_grid_shape(
             grid=grid, unmasked_sparse_shape=pix.shape
         )
 
         pixelization_grid = aa.GridVoronoi(
-            grid_1d=sparse_grid.sparse,
+            grid=sparse_grid.sparse,
             nearest_pixelization_1d_index_for_mask_1d_index=sparse_grid.sparse_1d_index_for_mask_1d_index,
         )
 
@@ -680,7 +680,7 @@ class TestVoronoiMagnification:
     def test__3x3_simple_grid__include_mask_and_sub_grid(self):
 
         mask = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [
                     [True, True, True, True, True],
                     [True, True, False, True, True],
@@ -721,12 +721,12 @@ class TestVoronoiMagnification:
         grid = aa.MaskedGrid.manual_1d(grid=grid, mask=mask)
 
         pix = aa.pix.VoronoiMagnification(shape=(3, 3))
-        sparse_grid = grids.SparseGrid.from_grid_and_unmasked_2d_grid_shape(
+        sparse_grid = grids.GridSparse.from_grid_and_unmasked_2d_grid_shape(
             grid=grid, unmasked_sparse_shape=pix.shape
         )
 
         pixelization_grid = aa.GridVoronoi(
-            grid_1d=sparse_grid.sparse,
+            grid=sparse_grid.sparse,
             nearest_pixelization_1d_index_for_mask_1d_index=sparse_grid.sparse_1d_index_for_mask_1d_index,
         )
 
@@ -789,7 +789,7 @@ class TestVoronoiMagnification:
     def test__3x3_simple_grid__include_mask_with_offset_centre(self):
 
         mask = aa.Mask.manual(
-            mask_2d=np.array(
+            mask=np.array(
                 [
                     [True, True, True, True, True, True, True],
                     [True, True, True, True, False, True, True],
@@ -809,12 +809,12 @@ class TestVoronoiMagnification:
         grid = aa.MaskedGrid.manual_1d(grid=grid, mask=mask)
 
         pix = aa.pix.VoronoiMagnification(shape=(3, 3))
-        sparse_grid = grids.SparseGrid.from_grid_and_unmasked_2d_grid_shape(
+        sparse_grid = grids.GridSparse.from_grid_and_unmasked_2d_grid_shape(
             grid=grid, unmasked_sparse_shape=pix.shape
         )
 
         pixelization_grid = aa.GridVoronoi(
-            grid_1d=sparse_grid.sparse,
+            grid=sparse_grid.sparse,
             nearest_pixelization_1d_index_for_mask_1d_index=sparse_grid.sparse_1d_index_for_mask_1d_index,
         )
 
@@ -893,10 +893,10 @@ class TestVoronoiMagnification:
         )
 
         real_space_mask = aa.Mask.manual(
-            mask_2d=real_space_mask, pixel_scales=0.1, sub_size=1
+            mask=real_space_mask, pixel_scales=0.1, sub_size=1
         )
 
-        grid = aa.MaskedGrid.from_mask(mask=real_space_mask)
+        grid = aa.Grid.from_mask(mask=real_space_mask)
 
         pix = aa.pix.VoronoiMagnification(shape=(7, 7))
 
